@@ -1,25 +1,23 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2; -*- */
-/* logview-app.c - logview application singleton
+/* Copyright (C) 2008 Cosimo Cecchi <cosimoc@gnome.org>
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * Copyright (C) 2008 Cosimo Cecchi <cosimoc@gnome.org>
+ * This file is part of MATE Utils.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * MATE Utils is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-/* logview-app.c */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -94,7 +92,7 @@ typedef struct {
 
 /* adapted from sysklogd sources */
 static GSList*
-parse_syslog ()
+parse_syslog (void)
 {
   char cbuf[BUFSIZ];
   char *cline, *p;
@@ -187,7 +185,7 @@ enumerate_next_files_async_cb (GObject *source,
       continue;
     }
 
-    if (type != (G_FILE_TYPE_REGULAR || G_FILE_TYPE_SYMBOLIC_LINK) ||
+    if (((type != G_FILE_TYPE_REGULAR) && (type != G_FILE_TYPE_SYMBOLIC_LINK)) ||
         !g_content_type_is_a (content_type, "text/plain"))
     {
       g_object_unref (info);
