@@ -1,20 +1,20 @@
-/* gdict-context.c - Abstract class for dictionary contexts
+/* Copyright (C) 2005 Emmanuele Bassi <ebassi@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * Copyright (C) 2005  Emmanuele Bassi <ebassi@gmail.com>
+ * This file is part of MATE Utils.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * MATE Utils is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * You should have received a copy of the GNU General Public License
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 /**
@@ -37,7 +37,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include <glib/gi18n-lib.h>
@@ -49,10 +49,8 @@
 #include "gdict-context-private.h"
 #include "gdict-private.h"
 
-
 static void gdict_context_class_init (gpointer g_iface, void *user_data);
 
-
 GType
 gdict_context_get_type (void)
 {
@@ -66,6 +64,12 @@ gdict_context_get_type (void)
         NULL,                       /* base_init */
         NULL,                       /* base_finalize */
         (GClassInitFunc) gdict_context_class_init,
+        NULL,                       /* class_finalize */
+        NULL,                       /* class_data */
+        0,                          /* instance_size */
+        0,                          /* n_preallocs */
+        NULL,                       /* instance_init */
+        NULL                        /* value_table */
       };
 
       context_type = g_type_register_static (G_TYPE_INTERFACE,
@@ -77,7 +81,6 @@ gdict_context_get_type (void)
   return context_type;
 }
 
-
 static void
 gdict_context_class_init (gpointer g_iface, void *user_data)
 {
@@ -411,8 +414,6 @@ gdict_context_define_word (GdictContext  *context,
   							 error);
 }
 
-
-
 /*****************
  * GdictDatabase *
  *****************/
@@ -521,8 +522,6 @@ gdict_database_get_full_name (GdictDatabase *db)
   return db->full_name;
 }
 
-
-
 /*****************
  * GdictStrategy *
  *****************/
@@ -629,8 +628,6 @@ gdict_strategy_get_description (GdictStrategy *strat)
   return strat->description;
 }
 
-
-
 /**************
  * GdictMatch *
  **************/
@@ -736,8 +733,6 @@ gdict_match_get_database (GdictMatch *match)
   return match->database;
 }
 
-
-
 /*******************
  * GdictDefinition *
  *******************/
