@@ -540,7 +540,7 @@ create_interactive_dialog (void)
                     G_CALLBACK (interactive_dialog_response_cb),
                     NULL);
 
-  g_signal_connect (G_OBJECT (retval), "key-press-event",
+  g_signal_connect (retval, "key-press-event",
                     G_CALLBACK(key_press_cb),
                     NULL);
 
@@ -760,7 +760,6 @@ screenshot_dialog_response_cb (GtkDialog *d,
     }
 }
 
-
 static void
 run_dialog (ScreenshotDialog *dialog)
 {
@@ -1113,7 +1112,6 @@ prepare_screenshot_timeout (gpointer data)
   return FALSE;
 }
 
-
 static gchar *
 get_desktop_dir (void)
 {
@@ -1219,36 +1217,6 @@ save_options (void)
                          BORDER_EFFECT_KEY, border_effect);
 }
 
-
-static void
-register_screenshooter_icon (GtkIconFactory * factory)
-{
-  GtkIconSource *source;
-  GtkIconSet *icon_set;
-
-  source = gtk_icon_source_new ();
-  gtk_icon_source_set_icon_name (source, SCREENSHOOTER_ICON);
-
-  icon_set = gtk_icon_set_new ();
-  gtk_icon_set_add_source (icon_set, source);
-
-  gtk_icon_factory_add (factory, SCREENSHOOTER_ICON, icon_set);
-  gtk_icon_set_unref (icon_set);
-  gtk_icon_source_free (source);
-}
-
-static void
-screenshooter_init_stock_icons (void)
-{
-  GtkIconFactory *factory;
-
-  factory = gtk_icon_factory_new ();
-  gtk_icon_factory_add_default (factory);
-
-  register_screenshooter_icon (factory);
-  g_object_unref (factory);
-}
-
 void
 loop_dialog_screenshot (void)
 {
@@ -1323,7 +1291,7 @@ main (int argc, char *argv[])
     { "border-effect", 'e', 0, G_OPTION_ARG_STRING, &border_effect_arg, N_("Effect to add to the border (shadow, border or none)"), N_("effect") },
     { "interactive", 'i', 0, G_OPTION_ARG_NONE, &interactive_arg, N_("Interactively set options"), NULL },
     { "version", 0, 0, G_OPTION_ARG_NONE, &version_arg, N_("Print version information and exit"), NULL },
-    { NULL },
+    { NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL },
   };
 
 #ifdef ENABLE_NLS
@@ -1368,7 +1336,6 @@ main (int argc, char *argv[])
   }
 
   gtk_window_set_default_icon_name (SCREENSHOOTER_ICON);
-  screenshooter_init_stock_icons ();
 
   settings = g_settings_new (MATE_SCREENSHOT_SCHEMA);
   load_options ();
